function varargout = delayedGroupDemo(varargin)
% DELAYEDGROUPDEMO M-file for delayedGroupDemo.fig
% 
% See my Delayed Color Radio Group Demo documents(DelayedGroupDemo.doc)
% for more information.
%
% Created by Dr. C. S. Tritt
% Last revised: 1/24/07 (version 1.0)
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help delayedGroupDemo

% Last Modified by GUIDE v2.5 24-Jan-2007 14:33:03

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @delayedGroupDemo_OpeningFcn, ...
                   'gui_OutputFcn',  @delayedGroupDemo_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

% --- Executes just before delayedGroupDemo is made visible.
function delayedGroupDemo_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to delayedGroupDemo (see VARARGIN)

% Choose default command line output for delayedGroupDemo
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes delayedGroupDemo wait for user response (see UIRESUME)
% uiwait(handles.figure1);

% --- Outputs from this function are returned to the command line.
function varargout = delayedGroupDemo_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

% --- Executes on button press in doItButton.
function doItButton_Callback(hObject, eventdata, handles)
% hObject    handle to doItButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

if get(handles.redRadio, 'Value') == 1
   set(handles.colorPanel, 'backgroundColor', [1 0 0]);
elseif get(handles.greenRadio, 'Value') == 1
   set(handles.colorPanel, 'backgroundColor', [0 0.7 0]);
elseif get(handles.blueRadio, 'Value') == 1
   set(handles.colorPanel, 'backgroundColor', [0 0 1]);        
end